set stty_init -echo

################################################################
# proc challResp {pattern response info}--
#    Hold a single interchange challenge/response conversation.
# Arguments
#   pattern:	the pattern to wait for as a challenge
#   response:   The response to this pattern.
#   info:       Identifying information about this interaction
#               for use with exception reporting.
# 
# Results
#   
# 
proc challResp {pattern response info} {
  global spawn_id
  expect {
    $pattern {exp_send "$response\n"}
    timeout  {error "Timeout at $info" "Timeout at $info"}
    eof      {error "Eof at $info" "Eof at $info"}
  }
  return ""
}

################################################################
# proc runTest {}--
#    Run an FTP login test
# Arguments
#   NONE
# Results
#   Returns a list of result (Success/Fail) and optional failure message.
# 
proc runTest {} {
  global Client spawn_id errorInfo 

  set errorInfo ""

  spawn ftp $Client(IP)
  
  set conversations {
    "Name" "$Client(User)" "Name prompt"
    "word:" "$Client(Passwd)" "Password prompt"
    "Guest login ok" {} "FTP application prompt"
  }

  foreach {challenge response msg} $conversations {
    set fail [catch {challResp $challenge [subst $response] $msg} result]
    if {$fail} {break;}
  }
  
  array set lookup {0 "Success" 1 "Fail"}

  puts $Client(sock) [list RESULT: $lookup($fail) $result]
}  

proc processLine {channel} {
    global Client

    set len [gets $channel line]

    if {[eof $channel]} {
        close $channel
	return
    }
    eval $line
}


set Client(sock) [socket 127.0.0.1 23456]
fileevent $Client(sock) readable "processLine $Client(sock)"
fconfigure $Client(sock) -buffering line

puts $Client(sock) ready

set Client(done) 0
vwait Client(done)

